@@ -1,6 +1,6 @@
 ;;; ecb-create-layout.el --- creating new layouts
 
-;; Copyright (C) 2000 - 2003 Jesper Nordenberg,
+;; Copyright (C) 2000 - 2005 Jesper Nordenberg,
 ;;                           Klaus Berndl,
 ;;                           Kevin A. Burton,
 ;;                           Free Software Foundation, Inc.
@@ -26,7 +26,7 @@
 ;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-;; $Id: ecb-create-layout.el,v 1.29 2004/05/06 09:02:08 berndl Exp $
+;; $Id: ecb-create-layout.el,v 1.32 2005/05/23 15:49:15 berndl Exp $
 
 ;;; Commentary:
 ;;
@@ -43,6 +43,10 @@
 (eval-when-compile
   (require 'silentcomp))
 
+(eval-when-compile
+  ;; to avoid compiler grips
+  (require 'cl))
+
 (require 'ecb-mode-line)
 (require 'ecb-util)
 (require 'ecb-compilation)
@@ -84,7 +88,7 @@
 (defconst ecb-create-layout-buf-prefix " *ECB-LC-")
 (defconst ecb-create-layout-frame-name "Creation of a new ECB-layout")
 (defconst ecb-create-layout-all-buf-types
-  '("directories" "history" "methods" "sources" "speedbar"))
+  '("directories" "history" "methods" "sources" "speedbar" "analyse"))
 
 (defconst ecb-create-layout-help-text-left-right
   "
@@ -105,14 +109,13 @@
       - How to split: \"at-point\", \"half\" or
         \"other\" (i.e. you can specify any fraction
         between 0.1 and 0.9)
-      - Which type (\"directories\", \"sources\",
-        \"methods\", \"history\", \"speedbar\") the
-        current window should be.
+      - Which type the current window should be
+        \(see description of C-t below).
  C-u: Unsplit, ie. delete current window
  C-t: Give the current window a built-in type
       (\"directories\", \"sources\", \"methods\",
-      \"history\", \"speedbar\") or any arbitrary user-
-      defined type (\"other\"). See the Online-manual!
+      \"history\" etc.) or any arbitrary user-defined
+      type (\"other\"). See the Online-manual!
 
  C-c: Cancel layout creation. This does not save the
       layout. Deletes this frame.
@@ -140,11 +143,10 @@
       - If \"vertical\" or \"horizontal\" split
       - How to split: \"at-point\", \"half\" or \"other\" (i.e. you can specify any
         fraction between 0.1 and 0.9)
-      - Which type (\"directories\", \"sources\", \"methods\", \"history\", \"speedbar\")
-        the current window should be.
+      - Which type the current window should be \(see description of C-t below).
  C-u: Unsplit, ie. delete current window
  C-t: Give the current window a built-in type (\"directories\", \"sources\", \"methods\",
-      \"history\", \"speedbar\") or any arbitrary user-defined type (\"other\").
+      \"history\" etc.) or any arbitrary user-defined type (\"other\").
 
  C-c: Cancel layout creation. This does not save the layout. Deletes this frame.
  C-q: Save current defined layout and quit the layout creation. You will be asked for a
@@ -157,9 +159,9 @@
 (defconst ecb-create-layout-file-header
      "
 
-;; Copyright (C) 2001 Jesper Nordenberg
-;; Copyright (C) 2001 Free Software Foundation, Inc.
-;; Copyright (C) 2001 Klaus Berndl <klaus.berndl@sdm.de>
+;; Copyright (C) 2001 - 2005 Jesper Nordenberg
+;; Copyright (C) 2001 - 2005 Free Software Foundation, Inc.
+;; Copyright (C) 2001 - 2005 Klaus Berndl <klaus.berndl@sdm.de>
 
 ;; Author: Klaus Berndl <klaus.berndl@sdm.de>
 ;; Maintainer: Klaus Berndl <klaus.berndl@sdm.de>
@@ -230,28 +232,40 @@
   (setq ecb-create-layout-generated-lisp nil)
   (setq ecb-create-layout-gen-counter 0))
 
+(defvar ecb-create-layout-frame-deleted nil)
+
 (defadvice delete-frame (before ecb-create-layout)
   "Ensure calling `ecb-create-layout-cancel' during deleting the
-layout-creation frame."
+layout-creation frame. Does nothing for any other other frame!"
   (let ((frame (or (ad-get-arg 0) (selected-frame))))
     (when (ecb-string= (ecb-frame-parameter frame 'name)
                        ecb-create-layout-frame-name)
+      (setq ecb-create-layout-frame-deleted t)
       (ecb-create-layout-cancel))))
 
+(defadvice delete-frame (after ecb-create-layout)
+  "Ensures correct deleting of the layout-creation frame. Does nothing for any
+other other frame!"
+  (when ecb-create-layout-frame-deleted
+    (setq ecb-create-layout-frame-deleted nil)
+    (ecb-activate))
+  (ad-disable-advice 'delete-frame 'after 'ecb-create-layout)
+  (ad-activate 'delete-frame))
+  
+
 (defun ecb-create-layout-frame-ok ()
   "Return not nil if current frame is the `ecb-create-layout-frame'"
   (and ecb-create-layout-frame
        (frame-live-p ecb-create-layout-frame)
        (equal (selected-frame) ecb-create-layout-frame)))
 
-
 (defun ecb-create-layout-cancel (&rest ignore)
   "Cancel layout-creation without saving the layout."
   (interactive)
   (when (ecb-create-layout-frame-ok)
     (ecb-create-layout-clear-all (interactive-p))
     (message "ECB Layout Creation canceled - the layout is not saved!")
-    (ecb-activate)))
+    (and (interactive-p) (ecb-activate))))
 
 (defun ecb-create-layout-clear-all (&optional delete-frame)
   "Resets all stuff to state before `ecb-create-new-layout' was called. If
@@ -272,8 +286,8 @@ DELETE-FRAME is not nil then the new created frame will be deleted and the
       (setq minor-mode-map-alist
             ecb-create-layout-old-minor-mode-map-alist))
   ;; restore horiz. scrolling
-  (if ecb-running-emacs-21
-      (setq automatic-hscrolling ecb-create-layout-old-hscroll))
+  (unless ecb-running-xemacs
+    (setq automatic-hscrolling ecb-create-layout-old-hscroll))
   ;; for XEmacs restore these maps
   (if ecb-running-xemacs
       (progn
@@ -671,15 +685,16 @@ never selects the edit-window."
     (setq ecb-create-layout-type (intern (ecb-query-string
                                           "Location of the the ECB-tree-windows:"
                                           '("left" "right" "top" "left-right")))))
-  (cond ((equal ecb-create-layout-type 'left)
-         (ecb-split-hor ecb-windows-width))
-        ((equal ecb-create-layout-type 'right)
-         (ecb-split-hor (- ecb-windows-width) t))
-        ((equal ecb-create-layout-type 'top)
-         (ecb-split-ver ecb-windows-height))
-        (t
-         (ecb-split-hor (- (* 0.667 ecb-windows-width)) t)
-         (ecb-split-hor (* 0.667 ecb-windows-width) nil t)))
+  (case ecb-create-layout-type
+    (left
+     (ecb-split-hor ecb-windows-width))
+    (right
+     (ecb-split-hor (- ecb-windows-width) t))
+    (top
+     (ecb-split-ver ecb-windows-height))
+    (otherwise
+     (ecb-split-hor (- (* 0.667 ecb-windows-width)) t)
+     (ecb-split-hor (* 0.667 ecb-windows-width) nil t)))
   ;; we set the buffer in the big edit-window
   (ecb-create-layout-new-buffer t)
   ;; now we insert the help in the edit-window
@@ -705,47 +720,37 @@ never selects the edit-window."
 
 (defun ecb-create-layout-make-frame ()
   "Create a new frame for the layout creation process and return it."
-  (cond (ecb-running-xemacs
-         (make-frame `((name . ,ecb-create-layout-frame-name)
-                       (minibuffer . t)
-                       (user-position . t)
-                       (width . ,ecb-create-layout-frame-width)
-                       (height . ,ecb-create-layout-frame-height)
-                       (default-toolbar-visible-p . nil)
-                       (left-toolbar-visible-p . nil)
-                       (right-toolbar-visible-p . nil)
-                       (top-toolbar-visible-p . nil)
-                       (bottom-toolbar-visible-p . nil)
-                       (default-gutter-visible-p . nil)
-                       (left-gutter-visible-p . nil)
-                       (right-gutter-visible-p . nil)
-                       (top-gutter-visible-p . nil)
-                       (bottom-gutter-visible-p . nil)
-                       (has-modeline-p . t)
-                       (use-left-overflow . nil)
-                       (vertical-scrollbar-visible-p . nil)
-                       (horizontal-scrollbar-visible-p . nil)
-                       (use-right-overflow . nil)
-                       (menubar-visible-p . nil))))
-        (ecb-running-emacs-21
-         (make-frame `((name . ,ecb-create-layout-frame-name)
-                       (minibuffer . t)
-                       (user-position . t)
-                       (width . ,ecb-create-layout-frame-width)
-                       (height . ,ecb-create-layout-frame-height)
-                       (vertical-scroll-bars . nil)
-                       (horizontal-scroll-bars . nil)
-                       (tool-bar-lines . 0)
-                       (menu-bar-lines . 0))))
-        (t ;; Emacs 20
-         (make-frame `((name . ,ecb-create-layout-frame-name)
-                       (minibuffer . t)
-                       (user-position . t)
-                       (width . ,ecb-create-layout-frame-width)
-                       (height . ,ecb-create-layout-frame-height)
-                       (vertical-scroll-bars . nil)
-                       (menu-bar-lines . 0))))))
-         
+  (if ecb-running-xemacs
+      (make-frame `((name . ,ecb-create-layout-frame-name)
+                    (minibuffer . t)
+                    (user-position . t)
+                    (width . ,ecb-create-layout-frame-width)
+                    (height . ,ecb-create-layout-frame-height)
+                    (default-toolbar-visible-p . nil)
+                    (left-toolbar-visible-p . nil)
+                    (right-toolbar-visible-p . nil)
+                    (top-toolbar-visible-p . nil)
+                    (bottom-toolbar-visible-p . nil)
+                    (default-gutter-visible-p . nil)
+                    (left-gutter-visible-p . nil)
+                    (right-gutter-visible-p . nil)
+                    (top-gutter-visible-p . nil)
+                    (bottom-gutter-visible-p . nil)
+                    (has-modeline-p . t)
+                    (use-left-overflow . nil)
+                    (vertical-scrollbar-visible-p . nil)
+                    (horizontal-scrollbar-visible-p . nil)
+                    (use-right-overflow . nil)
+                    (menubar-visible-p . nil)))
+    (make-frame `((name . ,ecb-create-layout-frame-name)
+                  (minibuffer . t)
+                  (user-position . t)
+                  (width . ,ecb-create-layout-frame-width)
+                  (height . ,ecb-create-layout-frame-height)
+                  (vertical-scroll-bars . nil)
+                  (horizontal-scroll-bars . nil)
+                  (tool-bar-lines . 0)
+                  (menu-bar-lines . 0)))))
 
 ;; TODO: Klaus Berndl <klaus.berndl@sdm.de>: Wir mssen ev. ECB vorher
 ;; deaktivieren, da sonst ein 2. ECB-menu entsteht. Beim C-c oder C-q eben
@@ -772,6 +777,7 @@ never selects the edit-window."
   (raise-frame ecb-create-layout-frame)
   (select-frame ecb-create-layout-frame)
   (ad-enable-advice 'delete-frame 'before 'ecb-create-layout)
+  (ad-enable-advice 'delete-frame 'after 'ecb-create-layout)
   (ad-activate 'delete-frame)
 
   ;; global map
@@ -783,7 +789,7 @@ never selects the edit-window."
   (setq minor-mode-map-alist nil)
 
   ;; horiz. scrolling
-  (when ecb-running-emacs-21
+  (unless ecb-running-xemacs
     (setq ecb-create-layout-old-hscroll automatic-hscrolling)
     (setq automatic-hscrolling nil))
 
@@ -848,6 +854,15 @@ unbound."
            (ecb-create-layout-buffer-type)
            (ecb-create-layout-buffer-factor)))
 
+;; Klaus Berndl <klaus.berndl@sdm.de>: Cause of the magic autostart stuff of
+;; the advice-package we must disable at load-time all these advices!!
+;; Otherwise would just loading ecb (not activating!) activate each advice
+;; AFTER the FIRST usage of our advices!!
+(ad-disable-advice 'delete-frame 'after 'ecb-create-layout)
+(ad-disable-advice 'delete-frame 'before 'ecb-create-layout)
+(ad-activate 'delete-frame)
+
+
 (silentcomp-provide 'ecb-create-layout)
 
 ;; ecb-help.el ends here
