@@ -1,6 +1,6 @@
 ;;; ecb-examples.el --- examples for using ECB with Elisp
 
-;; Copyright (C) 2000 - 2003 Jesper Nordenberg,
+;; Copyright (C) 2000 - 2005 Jesper Nordenberg,
 ;;                           Klaus Berndl,
 ;;                           Kevin A. Burton,
 ;;                           Free Software Foundation, Inc.
@@ -26,7 +26,7 @@
 ;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-;; $Id: ecb-examples.el,v 1.13 2004/05/06 09:02:08 berndl Exp $
+;; $Id: ecb-examples.el,v 1.20 2005/06/20 14:34:20 berndl Exp $
 
 ;;; Commentary:
 ;;
@@ -64,7 +64,11 @@
 
 (require 'ecb-util)
 (require 'ecb-layout)
+(require 'ecb-common-browser)
 
+(eval-when-compile
+  ;; to avoid compiler grips
+  (require 'cl))
 
 ;; ---------------------------------------------------------------------------
 ;; --- Code for the bufferinfo buffer ----------------------------------------
@@ -149,18 +153,31 @@ it will be called autom. with `ecb-current-buffer-sync-hook'."
                                            (buffer-name (current-buffer)))))))
 
 
+;; Two conveniance-commands for the user
 
-;; The "dedicated setter" function for the bufferinfo-buffer. See
-;; `ecb-with-dedicated-window' for an explanation.
+(defun ecb-maximize-bufferinfo-window ()
+  "Maximize the bufferinfo-window.
+I.e. delete all other ECB-windows, so only one ECB-window and the
+edit-window\(s) are visible \(and maybe a compile-window). Works
+also if the ECB-analyse-window is not visible in current layout."
+  (interactive)
+  (ecb-maximize-ecb-buffer ecb-examples-bufferinfo-buffer-name t))
 
-(defun ecb-examples-set-bufferinfo-buffer ()
+(defun ecb-goto-bufferinfo-window ()
+  "Make the bufferinfo-window the current window."
+  (interactive)
+  (ecb-goto-ecb-window ecb-examples-bufferinfo-buffer-name))
+
+
+;; The "window-dedicator"-function for the bufferinfo-buffer. See
+;; `defecb-window-dedicator' for an explanation.
+
+(defecb-window-dedicator ecb-examples-set-bufferinfo-buffer
+    ecb-examples-bufferinfo-buffer-name
   "Set the buffer in the current window to the bufferinfo-buffer and make this
 window dedicated for this buffer."
-  (ecb-with-dedicated-window
-      ecb-examples-bufferinfo-buffer-name
-      'ecb-examples-set-bufferinfo-buffer
-    (switch-to-buffer (get-buffer-create ecb-examples-bufferinfo-buffer-name))
-    (setq buffer-read-only t)))
+  (switch-to-buffer (get-buffer-create ecb-examples-bufferinfo-buffer-name))
+  (setq buffer-read-only t))
 
 ;; ---------------------------------------------------------------------------
 ;; --- Code for the action buffer --------------------------------------------
@@ -232,7 +249,7 @@ if clicks onto \[next] the buffer in the edit-window is scrolled down.
 Otherwise nothing will be done."
   (interactive "e")
   (mouse-set-point e)
-  (let ((line (buffer-substring (ecb-line-beginning-pos) (ecb-line-end-pos))))
+  (let ((line (ecb-buffer-substring (ecb-line-beginning-pos) (ecb-line-end-pos))))
     (cond ((string-match "prior" line)
            (ecb-select-edit-window)
            (call-interactively 'scroll-down))
@@ -242,16 +259,30 @@ Otherwise nothing will be done."
           (t nil))))
 
 
+;; Two conveniance-commands for the user
 
-;; The "dedicated setter" function for the bufferinfo-buffer. See
-;; `ecb-with-dedicated-window' for an explanation.
+(defun ecb-maximize-action-window ()
+  "Maximize the action-window.
+I.e. delete all other ECB-windows, so only one ECB-window and the
+edit-window\(s) are visible \(and maybe a compile-window). Works
+also if the ECB-analyse-window is not visible in current layout."
+  (interactive)
+  (ecb-maximize-ecb-buffer ecb-examples-action-buffer-name t))
 
-(defun ecb-examples-set-action-buffer ()
+(defun ecb-goto-action-window ()
+  "Make the action-window the current window."
+  (interactive)
+  (ecb-goto-ecb-window ecb-examples-action-buffer-name))
+
+
+;; The "window-dedicator"-function for the action-buffer. See
+;; `defecb-window-dedicator' for an explanation.
+
+(defecb-window-dedicator ecb-examples-set-action-buffer
+    (buffer-name (ecb-examples-action-buffer-create))
   "Set the buffer in the current window to the action-buffer and make this
 window dedicated for this buffer."
-  (let ((buf-name (buffer-name (ecb-examples-action-buffer-create))))
-    (ecb-with-dedicated-window buf-name 'ecb-examples-set-action-buffer
-      (switch-to-buffer (buffer-name (ecb-examples-action-buffer-create))))))
+  (switch-to-buffer (buffer-name (ecb-examples-action-buffer-create))))
 
 ;; ---------------------------------------------------------------------------
 ;; --- The layout definition with a bufferinfo- and a action-buffer -----------
@@ -283,7 +314,7 @@ window dedicated for this buffer."
    -------------------------------------------------------
 
 If you have not set a compilation-window in `ecb-compile-window-height' then
-the layout contains no durable compilation window and the other windows get a
+the layout contains no persistent compilation window and the other windows get a
 little more place.
 
 The top-left window always displays informations about the current buffer in
