@@ -1,6 +1,6 @@
 ;;; ecb-face.el --- all face-options of ECB
 
-;; Copyright (C) 2000 - 2003 Jesper Nordenberg,
+;; Copyright (C) 2000 - 2005 Jesper Nordenberg,
 ;;                           Klaus Berndl,
 ;;                           Kevin A. Burton,
 ;;                           Free Software Foundation, Inc.
@@ -26,7 +26,7 @@
 ;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-;; $Id: ecb-face.el,v 1.19 2003/11/04 17:39:40 berndl Exp $
+;; $Id: ecb-face.el,v 1.23 2005/02/28 11:31:58 berndl Exp $
 
 ;;; Commentary:
 
@@ -73,35 +73,35 @@ The parameters are set for the following display-types:
                                      FG-DARK-COL, BG-DARK-COL
 - t: HEIGHT, BOLD-P, ITALIC-P, INHERIT, FG-REST, BG-REST, REVERSE-VIDEO."
   `(list (list '((class color) (background light))
-               (append (if (and ,height ecb-running-emacs-21) (list :height ,height))
-                       (if ,bold-p (if ecb-running-emacs-21
+               (append (if (and ,height (not ecb-running-xemacs)) (list :height ,height))
+                       (if ,bold-p (if (not ecb-running-xemacs)
                                        (list :weight 'bold)
                                      (list :bold t)))
-                       (if ,italic-p (if ecb-running-emacs-21
+                       (if ,italic-p (if (not ecb-running-xemacs)
                                          (list :slant 'italic)
                                        (list :italic t)))
-                       (if (and ,inherit ecb-running-emacs-21) (list :inherit ,inherit))
+                       (if (and ,inherit (not ecb-running-xemacs)) (list :inherit ,inherit))
                        (if ,fg-light-col (list :foreground ,fg-light-col))
                        (if ,bg-light-col (list :background ,bg-light-col))))
          (list '((class color) (background dark))
-               (append (if (and ,height ecb-running-emacs-21) (list :height ,height))
-                       (if ,bold-p (if ecb-running-emacs-21
+               (append (if (and ,height (not ecb-running-xemacs)) (list :height ,height))
+                       (if ,bold-p (if (not ecb-running-xemacs)
                                        (list :weight 'bold)
                                      (list :bold t)))
-                       (if ,italic-p (if ecb-running-emacs-21
+                       (if ,italic-p (if (not ecb-running-xemacs)
                                          (list :slant 'italic)
                                        (list :italic t)))
-                       (if (and ,inherit ecb-running-emacs-21) (list :inherit ,inherit))
+                       (if (and ,inherit (not ecb-running-xemacs)) (list :inherit ,inherit))
                        (if ,fg-dark-col (list :foreground ,fg-dark-col))
                        (if ,bg-dark-col (list :background ,bg-dark-col))))
-         (list 't (append (if (and ,height ecb-running-emacs-21) (list :height ,height))
-                          (if ,bold-p (if ecb-running-emacs-21
+         (list 't (append (if (and ,height (not ecb-running-xemacs)) (list :height ,height))
+                          (if ,bold-p (if (not ecb-running-xemacs)
                                           (list :weight 'bold)
                                         (list :bold t)))
-                          (if ,italic-p (if ecb-running-emacs-21
+                          (if ,italic-p (if (not ecb-running-xemacs)
                                             (list :slant 'italic)
                                           (list :italic t)))
-                          (if (and ,inherit ecb-running-emacs-21) (list :inherit ,inherit))
+                          (if (and ,inherit (not ecb-running-xemacs)) (list :inherit ,inherit))
                           (if ,fg-rest (list :foreground ,fg-rest))
                           (if ,bg-rest (list :foreground ,bg-rest))
                           (if ,reverse-video-p (list :reverse-video t))))))
@@ -209,7 +209,7 @@ color etc."
   :group 'ecb-faces)
 
 (defcustom ecb-history-general-face 'ecb-default-general-face
-  "*Basic face for the ECB directory buffer.
+  "*Basic face for the ECB history buffer.
 This defines the basic face the whole history buffer should displayed with. If
 the face 'ecb-default-general-face' is used then the display of all
 ECB-tree-buffers can be changed by modifying only the face
@@ -348,6 +348,101 @@ Changes take first effect after finishing and reactivating ECB!"
                 (face :tag "Special face"
                       :value ecb-history-face)))
 
+(defface ecb-analyse-face (ecb-face-default nil nil nil
+                                            'ecb-default-highlight-face
+                                            "yellow" nil
+                                            "cornflower blue" "magenta"
+                                            nil nil t)
+  "*Define face used for highlighting current entry in the analyse buffer."
+  :group 'ecb-faces)
+
+(defcustom ecb-analyse-face 'ecb-default-highlight-face
+  "*Face used for highlighting current entry in the analyse buffer.
+If the face 'ecb-default-highlight-face' is used then the display of all
+ECB-tree-buffers can be changed by modifying only the face
+'ecb-default-highlight-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
+  :group 'ecb-face-options
+  :group 'ecb-analyse
+  :type '(radio (const :tag "Use ecb-default-highlight-face"
+                       :value ecb-default-highlight-face)
+                (face :tag "Special face"
+                      :value ecb-analyse-face)))
+
+(defface ecb-analyse-general-face (ecb-face-default 1.0 nil nil
+                                                    'ecb-default-general-face)
+  "*Basic face for the ECB analyse buffer.
+Its recommended to define here the font-family, the font-size, the basic
+color etc."
+  :group 'ecb-faces)
+
+(defcustom ecb-analyse-general-face 'ecb-default-general-face
+  "*Basic face for the ECB analyse buffer.
+This defines the basic face the whole history buffer should displayed with. If
+the face 'ecb-default-general-face' is used then the display of all
+ECB-tree-buffers can be changed by modifying only the face
+'ecb-default-general-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
+  :group 'ecb-face-options
+  :group 'ecb-analyse
+  :type '(radio (const :tag "Use ecb-default-general-face"
+                       :value ecb-default-general-face)
+                (face :tag "Special face"
+                      :value ecb-analyse-general-face)))
+
+(defface ecb-analyse-bucket-element-face (ecb-face-default nil nil nil
+                                                           'ecb-default-general-face
+                                                           "brown")
+  "*Face used for displaying elements of buckets in the ECB-analyse-buffer.
+
+In GNU Emacs 21.X this face inherits from the face 'ecb-default-general-face'.
+
+With XEmacs and GNU Emacs 20.X there is no inheritance-feature so if the
+buckets in the ECB-buffers should be displayed with the same basic
+attributes set by 'ecb-default-general-face' this set of basic attributes have
+to be set in 'ecb-analyse-bucket-node-face' too!"
+  :group 'ecb-faces)
+
+(defcustom ecb-analyse-bucket-element-face 'ecb-analyse-bucket-element-face
+  "*Basic face for displaying elements of buckets in the ECB-analyse-buffer.
+This defines the basic face for the elements of category-buckets like Context,
+Prefix, Completions etc. in the ECB-analyse-buffer.
+
+Changes take first effect after finishing and reactivating ECB!"
+  :group 'ecb-face-options
+  :group 'ecb-analyse
+  :type '(radio (const :tag "Use ecb-default-general-face"
+                       :value ecb-default-general-face)
+                (face :tag "Special face"
+                      :value ecb-analyse-bucket-element-face)))
+
+(defface ecb-analyse-bucket-node-face (ecb-face-default nil t nil
+                                                           'ecb-default-general-face)
+  "*Face used for displaying a bucket-node in the ECB-analyse-buffer.
+
+In GNU Emacs 21.X this face inherits from the face 'ecb-default-general-face'.
+
+With XEmacs and GNU Emacs 20.X there is no inheritance-feature so if the
+buckets in the ECB-buffers should be displayed with the same basic
+attributes set by 'ecb-default-general-face' this set of basic attributes have
+to be set in 'ecb-analyse-bucket-node-face' too!"
+  :group 'ecb-faces)
+
+(defcustom ecb-analyse-bucket-node-face 'ecb-analyse-bucket-node-face
+  "*Basic face for displaying a bucket-node in the ECB-analyse-buffer.
+This defines the basic face for the bucket-nodes like Context, Prefix,
+Completions etc. in the ECB-analyse-buffer.
+
+Changes take first effect after finishing and reactivating ECB!"
+  :group 'ecb-face-options
+  :group 'ecb-analyse
+  :type '(radio (const :tag "Use ecb-default-general-face"
+                       :value ecb-default-general-face)
+                (face :tag "Special face"
+                      :value ecb-analyse-bucket-node-face)))
+
 (defface ecb-tag-header-face (ecb-face-default nil nil nil nil nil nil
                                                "SeaGreen1" "SeaGreen1"
                                                nil nil t)
@@ -380,6 +475,34 @@ jumping to it by clicking onto a node in the methods buffer."
   :group 'ecb-face-options
   :type 'face)
 
+(defface ecb-source-read-only-face (ecb-face-default nil nil t)
+  "*Define a face for displaying read-only sources."
+  :group 'ecb-faces)
+ 
+(defcustom ecb-source-read-only-face
+  'ecb-source-read-only-face
+  "*Face for read-only sources."
+  :group 'ecb-sources
+  :group 'ecb-directories
+  :group 'ecb-face-options
+  :type 'face)
+
+(defface ecb-directory-not-accessible-face (ecb-face-default nil nil nil
+                                                             'ecb-default-general-face
+                                                             "gray60"
+                                                             "gray60"
+                                                             nil nil
+                                                             nil "gray60")
+  "*Define a face for displaying not accessible dirs in the directories buffer."
+  :group 'ecb-faces)
+ 
+(defcustom ecb-directory-not-accessible-face
+  'ecb-directory-not-accessible-face
+  "*Face for not accessible dirs in the directories buffer."
+  :group 'ecb-directories
+  :group 'ecb-face-options
+  :type 'face)
+
 (defface ecb-type-tag-class-face (ecb-face-default nil t)
   "*Define face used with option `ecb-type-tag-display'."
   :group 'ecb-faces)
