@@ -1,6 +1,6 @@
 ;;; ecb-jde.el --- ECB JDE integrations
 
-;; Copyright (C) 2000 - 2003 Jesper Nordenberg,
+;; Copyright (C) 2000 - 2005 Jesper Nordenberg,
 ;;                           Klaus Berndl,
 ;;                           Kevin A. Burton,
 ;;                           Free Software Foundation, Inc.
@@ -26,7 +26,7 @@
 ;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-;; $Id: ecb-jde.el,v 1.10 2004/08/03 09:37:21 berndl Exp $
+;; $Id: ecb-jde.el,v 1.15 2005/04/19 15:18:59 berndl Exp $
 
 ;;; Commentary:
 ;;
@@ -114,9 +114,11 @@ available."
                   ;; be extracted in an own function of JDE.
                   
                   ;; we have found the java-sourcefile. So lets display its
-                  ;; contents in the method-buffer of ECB
-                  (ecb-exec-in-methods-window
-                   (ecb-set-selected-source java-file-name nil t nil))))
+                  ;; contents in the method-buffer of ECB - we must select the
+                  ;; methods-window before because otherwise our automatically
+                  ;; buffer-sync would resync with current java-source-file.
+                  (if (ecb-window-select ecb-methods-buffer-name)
+                      (ecb-set-selected-source java-file-name nil t nil))))
             
             (ecb-error "Can not parse the thing at point!")))
       (message "You need JDE >= 2.2.6 and Senator for using this feature!"))))
@@ -158,14 +160,15 @@ is not available then `find-file' is called."
 
 (defun ecb-jde-update-ecb-source-paths ()
   (interactive)
-  (cond ((equal ecb-jde-set-directories-buffer-to-jde-sourcepath 'add)
-         (add-hook 'ecb-source-path-functions
-                   'ecb-jde-get-source-path))
-        ((equal ecb-jde-set-directories-buffer-to-jde-sourcepath 'replace)
-         (setq ecb-source-path (ecb-jde-get-source-path)))
-        (t
-         (remove-hook 'ecb-source-path-functions
-                      'ecb-jde-get-source-path)))
+  (case ecb-jde-set-directories-buffer-to-jde-sourcepath
+    (add
+     (add-hook 'ecb-source-path-functions
+               'ecb-jde-get-source-path))
+    (replace
+     (setq ecb-source-path (ecb-jde-get-source-path)))
+    (otherwise
+     (remove-hook 'ecb-source-path-functions
+                  'ecb-jde-get-source-path)))
   (ecb-update-directories-buffer))
 
 
@@ -181,7 +184,6 @@ is not available then `find-file' is called."
                 (function (lambda ()
                             (ecb-toggle-compile-window 1))))))
 
-
 (silentcomp-provide 'ecb-jde)
 
 ;;; ecb-jde.el ends here
