@@ -1,6 +1,6 @@
 ;;; ecb-semantic-wrapper.el -- define wrappers for all semantic funcs/vars
 
-;; Copyright (C) 2000 - 2003 Jesper Nordenberg,
+;; Copyright (C) 2000 - 2005 Jesper Nordenberg,
 ;;                           Klaus Berndl,
 ;;                           Free Software Foundation, Inc.
 
@@ -23,7 +23,7 @@
 ;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-;; $Id: ecb-semantic-wrapper.el,v 1.15 2004/04/15 16:34:08 berndl Exp $
+;; $Id: ecb-semantic-wrapper.el,v 1.24 2005/03/30 12:50:35 berndl Exp $
 
 ;;; Commentary:
 
@@ -39,6 +39,8 @@
 
 
 (require 'semantic)
+(require 'semantic-ctxt)
+(require 'semantic-analyze)
 
 (defconst ecb-semantic-2-loaded (string-match "^2" semantic-version))
 (defconst ecb-semantic-2-beta-nr (if (and ecb-semantic-2-loaded
@@ -51,6 +53,10 @@
 (eval-when-compile
   (require 'silentcomp))
 
+(eval-when-compile
+  ;; to avoid compiler grips
+  (require 'cl))
+
 ;; semantic 1.X does not have this
 (silentcomp-defvar semanticdb-search-system-databases)
 (silentcomp-defvar semantic-format-use-images-flag)
@@ -118,7 +124,6 @@
     (semantic-current-nonterminal-parent      . semantic-current-tag-parent)
     (semantic-adopt-external-members          . semantic-adopt-external-members)
     (semantic-bucketize                       . semantic-bucketize)
-    (semantic-c-template-string               . semantic-c-template-string)
     (semantic-clear-toplevel-cache            . semantic-clear-toplevel-cache)
     (semantic-colorize-text                   . semantic--format-colorize-text)
     (semantic-current-nonterminal             . semantic-current-tag)
@@ -145,7 +150,11 @@
     (semantic-token-type                      . semantic-tag-type)
     (semantic-token-type-parent-superclass    . semantic-tag-type-superclass)
     (semantic-token-type-parent-implement     . semantic-tag-type-interfaces)
-    (semantic-token-with-position-p           . semantic-tag-with-position-p))
+    (semantic-token-with-position-p           . semantic-tag-with-position-p)
+    (semantic-analyze-current-context         . semantic-analyze-current-context)
+    (semantic-analyze-possible-completions    . semantic-analyze-possible-completions)
+    (semantic-get-local-arguments             . semantic-get-local-arguments)
+    (semantic-analyze-token-type              . semantic-analyze-tag-type))
   "Alist where the car is a function of semantic 1.X and the cdr is the
 equivalent new function of semantic 2.X. This alist should contain every
 function ECB uses from the semantic library.")
@@ -175,7 +184,6 @@ function of `semantic-token->text-functions' (rsp. for semantic 2.X
 equivalent new function of semanticdb 2.X. This alist should contain every
 function ECB uses from the semanticdb library.")
   
-
 ;; new let us create the aliase. Each alias has the name "ecb--"<function of
 ;; semantic 2.0>.
 (dolist (f-elem (append ecb--semantic-function-alist
@@ -186,12 +194,19 @@ function ECB uses from the semanticdb library.")
         (cdr f-elem)
       (car f-elem))))
 
+
 (defsubst ecb--semantic-tag (name class &rest ignore)
   "Create a new semantic tag with name NAME and tag-class CLASS."
   (if (fboundp 'semantic-tag)
       (apply 'semantic-tag name class ignore)
     (list name class nil nil nil nil)))
 
+(defsubst ecb--semantic-tag-new-variable (name type default-value &rest attributes)
+  "Create a semantic tag of class variable"
+  (if (fboundp 'semantic-tag-new-variable)
+      (apply 'semantic-tag-new-variable name type default-value attributes)
+    (list name 'variable nil nil nil nil)))
+
 (defsubst ecb--semantic--tag-set-overlay (tag overlay)
   "Set the overlay part of TAG with OVERLAY. OVERLAY can be an overlay or an
 unloaded buffer representation."
@@ -259,11 +274,10 @@ unloaded buffer representation."
     (defalias 'ecb--semantic-tag-components
       'semantic-tag-components)
   (defun ecb--semantic-tag-components (tag)
-    (cond ((equal (ecb--semantic-tag-class tag) 'type)
-           (ecb--semantic-tag-type-members tag))
-          ((equal (ecb--semantic-tag-class tag) 'function)
-           (ecb--semantic-tag-function-arguments tag))
-          (t nil))))
+    (case (ecb--semantic-tag-class tag)
+      (type (ecb--semantic-tag-type-members tag))
+      (function (ecb--semantic-tag-function-arguments tag))
+      (otherwise nil))))
 
 (if (fboundp 'semantic-flatten-tags-table)
     (defalias 'ecb--semantic-flatten-tags-table
@@ -362,28 +376,6 @@ with a file, then the cdr of the result-cons is nil."
         (cons (car result-nth)
               (ecb--semanticdb-full-filename (cdr result-nth)))
       (cons (car result-nth) nil))))
-    
-;; TODO: Klaus Berndl <klaus.berndl@sdm.de>: Add this code to semantic-el.el
-;; after a cedet-upgrade. It has to be added to the function
-;; `semantic-elisp-use-read' direct before the (t ...)-clause in the cond!
-;;
-;;    ((eq ts 'tree-buffer-defpopup-command)
-;;     ;; tree-buffer-defpopup-command
-;;     (semantic-tag-new-function
-;;      sn nil nil
-;;      :user-visible-flag nil
-;;      :documentation (semantic-elisp-do-doc (nth 2 rt))
-;;      )
-;;     )
-;;    ((eq ts 'ecb-layout-define)
-;;     ;; ecb-layout-define
-;;     (semantic-tag-new-function
-;;      tss nil (semantic-elisp-desymbolify (list (nth 2 rt)))
-;;      :user-visible-flag nil
-;;      :documentation (semantic-elisp-do-doc (nth 3 rt))
-;;      )
-;;     )
-
 
 (silentcomp-provide 'ecb-semantic-wrapper)
 
