@@ -1,6 +1,6 @@
 ;;; ecb-speedbar.el --- Integration of speedbar into ECB
 
-;; Copyright (C) 2000 - 2003 Jesper Nordenberg,
+;; Copyright (C) 2000 - 2005 Jesper Nordenberg,
 ;;                           Klaus Berndl,
 ;;                           Kevin A. Burton,
 ;;                           Free Software Foundation, Inc.
@@ -26,7 +26,7 @@
 ;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-;; $Id: ecb-speedbar.el,v 1.59 2004/05/06 09:02:05 berndl Exp $
+;; $Id: ecb-speedbar.el,v 1.66 2005/04/19 15:26:22 berndl Exp $
 
 ;;; Commentary:
 
@@ -69,6 +69,12 @@
 (require 'speedbar)
 (require 'ecb-util)
 (require 'ecb-semantic-wrapper)
+(require 'ecb-common-browser)
+
+(eval-when-compile
+  ;; to avoid compiler grips
+  (require 'cl))
+
 
 ;; imenu
 (silentcomp-defvar imenu--rescan-item)
@@ -93,6 +99,7 @@ Example: \(speedbar-change-initial-expansion-list \"buffers\")."
 
 (defconst ecb-speedbar-adviced-functions '((speedbar-click . around)
                                            (speedbar-frame-mode . around)
+                                           (dframe-select-attached-frame . after)
                                            (speedbar-get-focus . around)
                                            ;; we have to fix a bug there
                                            (dframe-mouse-set-point . around))
@@ -126,15 +133,16 @@ after clicking onto a filename in the speedbar."
              (equal (selected-frame) ecb-frame)
              (window-live-p (get-buffer-window ecb-speedbar-buffer-name))
              (and item
-                  (file-exists-p item)
-                  (not (file-directory-p item))))
+                  (ecb-file-exists-p item)
+                  (not (ecb-file-directory-p item))))
         (ecb-select-edit-window))))
 
 
 (defadvice speedbar-frame-mode (around ecb)
   "During running speedbar within ECB this command is disabled!"
   (if ecb-minor-mode
-      (message "This command is disabled during running speedbar within ECB!")
+      (when (interactive-p)
+        (ecb-info-message "speedbar-frame-mode takes no effect when running within ECB!"))
     ad-do-it))
 
 
@@ -167,21 +175,39 @@ the point was not set by `mouse-set-point'."
           (mouse-set-point e)))
     ;; We are not in XEmacs, OR we didn't click on a picture.
     (mouse-set-point e)))
-  
+
+;; Klaus Berndl <klaus.berndl@sdm.de>: we can not advice
+;; speedbar-select-attached-frame because this is a defsubst and is therefore
+;; inline compiled into all users of this function. So our advice would never
+;; take effect. But dframe-select-attached-frame is a defun so we can advice
+;; it!
+(defadvice dframe-select-attached-frame (after ecb)
+  "Run `ecb-speedbar-dframe-select-attached-window' but only if
+`dframe-after-select-attached-frame-hook' is not available."
+  (unless (boundp 'dframe-after-select-attached-frame-hook)
+    (ecb-speedbar-dframe-select-attached-window)))
+
+(defun ecb-speedbar-dframe-select-attached-window ()
+  (when (and ecb-last-edit-window-with-point
+             ecb-last-source-buffer
+             (window-live-p ecb-last-edit-window-with-point)
+             (equal (window-buffer ecb-last-edit-window-with-point)
+                    ecb-last-source-buffer))
+    (select-window ecb-last-edit-window-with-point)
+    (set-buffer ecb-last-source-buffer)))
 
 (defun ecb-speedbar-select-speedbar-window ()
   (ignore-errors
     (and (window-live-p (get-buffer-window ecb-speedbar-buffer-name))
          (select-window (get-buffer-window ecb-speedbar-buffer-name)))))
 
-
 (defun ecb-speedbar-set-buffer()
   "Set the speedbar buffer within ECB."
   (ecb-speedbar-activate)
   (set-window-buffer (selected-window)
                      (get-buffer-create ecb-speedbar-buffer-name))
-  (if ecb-running-emacs-21
-      (set (make-local-variable 'automatic-hscrolling) nil)))
+  (unless ecb-running-xemacs
+    (set (make-local-variable 'automatic-hscrolling) nil)))
 
 
 (defvar ecb-speedbar-verbosity-level-old nil)
@@ -198,6 +224,9 @@ future this could break."
   
   (run-hooks 'ecb-speedbar-before-activate-hook)
 
+  (add-hook 'dframe-after-select-attached-frame-hook
+            'ecb-speedbar-dframe-select-attached-window)
+
   ;;disable automatic speedbar updates... let the ECB handle this with
   ;;ecb-current-buffer-sync
   (speedbar-disable-update)
@@ -226,11 +255,9 @@ future this could break."
                       (lambda (event count)
                         (if (/= (event-button event) 1)
                             nil		; Do normal operations.
-                          (cond ((eq count 1)
-                                 (dframe-quick-mouse event))
-                                ((or (eq count 2)
-                                     (eq count 3))
-                                 (dframe-click event)))
+                          (case count
+                            (1 (dframe-quick-mouse event))
+                            ((2 3) (dframe-click event)))
                           ;; Don't do normal operations.
                           t))))
         ;; Enable mouse tracking in emacs
@@ -257,7 +284,7 @@ future this could break."
       (setq ecb-speedbar-verbosity-level-old speedbar-verbosity-level))
   (setq speedbar-verbosity-level 0)
 
-  (add-hook 'ecb-current-buffer-sync-hook
+  (add-hook 'ecb-current-buffer-sync-hook-internal
             'ecb-speedbar-current-buffer-sync)
 
   ;;reset the selection variable
@@ -268,6 +295,9 @@ future this could break."
   "Reset things as before activating speedbar by ECB"
   (ecb-disable-advices ecb-speedbar-adviced-functions)
   
+  (remove-hook 'dframe-after-select-attached-frame-hook
+               'ecb-speedbar-dframe-select-attached-window)
+
   (setq speedbar-frame nil)
   (setq dframe-attached-frame nil)
 
@@ -281,7 +311,7 @@ future this could break."
       (setq speedbar-verbosity-level ecb-speedbar-verbosity-level-old))
   (setq ecb-speedbar-verbosity-level-old nil)
   
-  (remove-hook 'ecb-current-buffer-sync-hook
+  (remove-hook 'ecb-current-buffer-sync-hook-internal
                'ecb-speedbar-current-buffer-sync)
 
   (when (and speedbar-buffer
@@ -315,11 +345,29 @@ future this could break."
           (ecb-default-directory (ecb-fix-filename default-directory)))
       (when (and (or (not (ecb-string= speedbar-default-directory
                                        ecb-default-directory))
-                     (ecb-string= speedbar-initial-expansion-list-name "buffers"))
+                     (member speedbar-initial-expansion-list-name
+                             ;; TODO: Klaus Berndl <klaus.berndl@sdm.de>: make
+                             ;; this customizable
+                             '("buffers" "Analyze")))
                  speedbar-buffer
                  (buffer-live-p speedbar-buffer))
         (ecb-speedbar-update-contents)))))
 
+(defun ecb-goto-window-speedbar ()
+  "Make the ECB-speedbar window the current window.
+This command does nothing if no integrated speedbar is visible in the
+ECB-frame."
+  (interactive)
+  (ecb-goto-ecb-window ecb-speedbar-buffer-name))
+
+(defun ecb-maximize-window-speedbar ()
+  "Maximize the ECB-speedbar-window.
+I.e. delete all other ECB-windows, so only one ECB-window and the
+edit-window\(s) are visible \(and maybe a compile-window). Does nothing if the
+speedbar-window is not visible within the ECB-frame."
+  (interactive)
+  (ecb-maximize-ecb-buffer ecb-speedbar-buffer-name t))
+
 
 ;; Handling of files which can not be parsed by semantic (i.e. there is no
 ;; semantic-grammar available) but which can be parsed by imenu and/or etags
@@ -346,63 +394,65 @@ Return NODE."
   (let ((new-node nil)
         (new-tag nil))
     (dolist (tag tag-list)
-      (cond ((null tag) nil)            ;this would be a separator
-            ((speedbar-generic-list-tag-p tag)
-             ;; the semantic tag for this tag
-             (setq new-tag (ecb--semantic-tag (car tag)
-                                              (intern (car tag))))
-             (ecb--semantic--tag-set-overlay new-tag (make-vector 2 (cdr tag)))
-             (ecb--semantic--tag-put-property new-tag 'ecb-speedbar-tag t)
-             (ecb-apply-user-filter-to-tags (list new-tag))
-             (when (not (ecb-tag-forbidden-display-p new-tag))
-               (tree-node-new (progn
-                                (set-text-properties
-                                 0 (length (car tag))
-                                 `(face ,ecb-method-non-semantic-face) (car tag))
-                                (car tag))
-                              0
-                              new-tag
-                              t
-                              node)))
-            ((speedbar-generic-list-positioned-group-p tag)
-             ;; the semantic tag for this tag
-             (setq new-tag (ecb--semantic-tag (car tag)
-                                              (intern (car tag))))
-             (ecb--semantic--tag-set-overlay new-tag
-                                             (make-vector 2 (car (cdr tag))))
-             (ecb--semantic--tag-put-property new-tag 'ecb-speedbar-tag t)
-             (ecb-apply-user-filter-to-tags (list new-tag))
-             (when (not (ecb-tag-forbidden-display-p new-tag))             
-               (ecb-create-non-semantic-tree
-                (setq new-node
-                      (tree-node-new (progn
-                                       (set-text-properties
-                                        0 (length (car tag))
-                                        `(face ,ecb-method-non-semantic-face) (car tag))
-                                       (car tag))
-                                     0
-                                     new-tag
-                                     nil node))
-                (cdr (cdr tag)))
-               (tree-node-set-expanded new-node
-                                       (member major-mode
-                                               ecb-non-semantic-methods-initial-expand))))
-            ((speedbar-generic-list-group-p tag)
-             (ecb-create-non-semantic-tree
-              (setq new-node
-                    (tree-node-new (progn
-                                     (set-text-properties
-                                      0 (length (car tag))
-                                      `(face ,ecb-method-non-semantic-face) (car tag))
-                                     (car tag))
-                                   1
-                                   nil nil node))
-              (cdr tag))
-             (tree-node-set-expanded new-node
-                                     (member major-mode
-                                             ecb-non-semantic-methods-initial-expand)))
-            (t (ecb-error "ecb-create-non-semantic-tree: malformed tag-list!")
-               )))
+      (typecase tag
+        (null nil) ;; this would be a separator
+        (speedbar-generic-list-tag
+         ;; the semantic tag for this tag
+         (setq new-tag (ecb--semantic-tag (car tag)
+                                          (intern (car tag))))
+         (ecb--semantic--tag-set-overlay new-tag (make-vector 2 (cdr tag)))
+         (ecb--semantic--tag-put-property new-tag 'ecb-speedbar-tag t)
+         (ecb-apply-user-filter-to-tags (list new-tag))
+         (when (not (ecb-tag-forbidden-display-p new-tag))
+           (tree-node-new (progn
+                            (set-text-properties
+                             0 (length (car tag))
+                             `(face ,ecb-method-non-semantic-face) (car tag))
+                            (car tag))
+                          0
+                          new-tag
+                          t
+                          node)))
+        (speedbar-generic-list-positioned-group
+         ;; the semantic tag for this tag
+         (setq new-tag (ecb--semantic-tag (car tag)
+                                          (intern (car tag))))
+         (ecb--semantic--tag-set-overlay new-tag
+                                         (make-vector 2 (car (cdr tag))))
+         (ecb--semantic--tag-put-property new-tag 'ecb-speedbar-tag t)
+         (ecb-apply-user-filter-to-tags (list new-tag))
+         (when (not (ecb-tag-forbidden-display-p new-tag))             
+           (ecb-create-non-semantic-tree
+            (setq new-node
+                  (tree-node-new (progn
+                                   (set-text-properties
+                                    0 (length (car tag))
+                                    `(face ,ecb-method-non-semantic-face) (car tag))
+                                   (car tag))
+                                 0
+                                 new-tag
+                                 nil node))
+            (cdr (cdr tag)))
+           (setf (tree-node->expanded new-node)
+                 (member major-mode
+                         ecb-non-semantic-methods-initial-expand))))
+        (speedbar-generic-list-group
+         (ecb-create-non-semantic-tree
+          (setq new-node
+                (tree-node-new (progn
+                                 (set-text-properties
+                                  0 (length (car tag))
+                                  `(face ,ecb-method-non-semantic-face) (car tag))
+                                 (car tag))
+                               1
+                               nil nil node))
+          (cdr tag))
+         (setf (tree-node->expanded new-node)
+               (member major-mode
+                       ecb-non-semantic-methods-initial-expand)))
+        (otherwise
+         (ecb-error "ecb-create-non-semantic-tree: malformed tag-list!")
+         )))
     node))
 
 (defun ecb-get-tags-for-non-semantic-files ()
