@@ -1,6 +1,6 @@
 ;;; ecb-tod.el --- ECB tip of the day
 
-;; Copyright (C) 2000 - 2003 Jesper Nordenberg,
+;; Copyright (C) 2000 - 2005 Jesper Nordenberg,
 ;;                           Klaus Berndl,
 ;;                           Kevin A. Burton,
 ;;                           Free Software Foundation, Inc.
@@ -26,7 +26,7 @@
 ;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-;; $Id: ecb-tod.el,v 1.18 2004/03/23 17:29:54 berndl Exp $
+;; $Id: ecb-tod.el,v 1.21 2005/04/19 15:26:22 berndl Exp $
 
 ;;; Commentary:
 ;;
@@ -78,7 +78,7 @@
     "Customize the look\&feel of the tree-buffers with `ecb-tree-expand-symbol-before' and `ecb-tree-indent'."
     "Customize the contents of the methods-buffer with `ecb-tag-display-function', `ecb-type-tag-display', `ecb-show-tags'."
     "Customize the main mouse-buttons of the tree-buffers with `ecb-primary-secondary-mouse-buttons'."
-    "Customize with `ecb-tree-RET-selects-edit-window' in which tree-buffer a RETURN selects the edit-window."
+    "Customize with `ecb-tree-do-not-leave-window-after-select' for which tree-buffers a selection doesn't leave the window."
     "Grep a directory \(recursive) by using the popup-menu \(the right mouse-button) in the directories buffer."
     "Customize the sorting of the sources with the option `ecb-sources-sort-method'."
     "Narrow the source-buffer to the selected tag in the methods-buffer with `ecb-tag-visit-post-actions'."
@@ -93,7 +93,7 @@
     "Use the POWER-click in the methods-buffer to narrow the clicked node in the edit-window."
     "Use the POWER-click in the sources- and history-buffer to get only an overlook of the source-contents."
     "Exclude not important sources from being displayed in the sources-buffer with `ecb-source-file-regexps'."
-    "Use left- and right-arrow for smart expanding/collapsing tree-buffer-nodes; see `ecb-tree-navigation-by-arrow'."
+    "Use left- and right-arrow for smart expanding/collapsing tree-buffer-nodes; see `ecb-tree-navigation-by-arrow'." ;;
     "Add personal key-bindings to the tree-buffers with `ecb-common-tree-buffer-after-create-hook'."
     "Add personal key-bindings to the directories-buffer with `ecb-directories-buffer-after-create-hook'."
     "Add personal key-bindings to the sources-buffer with `ecb-sources-buffer-after-create-hook'."
@@ -114,7 +114,12 @@
     "You can toggle having a compile window with `ecb-toggle-compile-window' if `ecb-compile-window-height' is not nil."
     "Start ECB automatically after Emacs is started. Use option `ecb-auto-activate'"
     "Maximize a tree-buffer via modeline - ECB supports the standard-mechanism of (X)Emacs for deleting other windows."
-    "Easy horizontal scrolling the tree-buffers with the mouse with [M-mouse-1] and [M-mouse-3]; see `ecb-tree-easy-hor-scroll'." ;;
+    "Easy horizontal scrolling the tree-buffers with the mouse with [M-mouse-1] and [M-mouse-3]; see `ecb-tree-easy-hor-scroll'."
+    "Expand and collapse very precisely the current node in a tree-buffer with commands in the popup-menu."
+    "Let ECB display the version-control-state of your files in the tree-buffers. See `ecb-vc-enable-support'."
+    "Work with remote paths (e.g. TRAMP-, ANGE-FTP-, or EFS-paths) as with local paths in `ecb-source-path'."
+    "Exclude certain files from being displayed in the history-buffer. See `ecb-history-exclude-file-regexps'."
+    "Get the most important options of ECB at a glance by viewing the customization group \"ecb-most-important\"."
     )
   "List of all available tips of the day.")
 
